#
# spec file for package python-asv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-asv
Version:        0.6.4
Release:        2.1
Summary:        Airspeed Velocity: A Python history benchmarking tool
License:        BSD-3-Clause AND MIT
Group:          Development/Languages/Python
URL:            https://github.com/airspeed-velocity/asv
Source:         https://files.pythonhosted.org/packages/source/a/asv/asv-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-PyYAML
Requires:       python-Pympler
Requires:       python-asv-runner >= 0.2.1
Requires:       python-build
Requires:       python-json5
Requires:       python-tabulate
Requires:       python-virtualenv
Suggests:       python-python-hglib >= 1.5
%if %{python_version_nodots} < 311
Requires:       python-tomli
%endif
# SECTION test requirements
BuildRequires:  %{python_module json5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tabulate}
BuildRequires:  git
# /SECTION
%python_subpackages

%description
airspeed velocity (asv) is a tool for benchmarking Python packages
over their lifetime.

It is designed to benchmark a single project over its lifetime using
a given suite of benchmarks. The results are displayed in an
interactive web frontend that requires only a basic static webserver
to host.

%prep
%autosetup -n asv-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/asv
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_expand rm %{buildroot}%{$python_sitearch}/asv/_rangemedian.cpp

%check
#MVY: there are so MANY tests failing inside OBS - like test_continuous calling pip and building bad command line
exit 0
# % pytest

%pre
%python_libalternatives_reset_alternative asv

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.rst
%python_alternative %{_bindir}/asv
%{python_sitearch}/asv/
%{python_sitearch}/asv-%{version}*-info

%changelog
* Mon Jun 16 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Tue Oct 15 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.4
  * ASV supports using JSONC as a configuration file (#1420)
  * Update deprecation for latest conda versions (#1403)
  * Fix runs for profiles commit results (#1404)
  * Internal pip parser now works for git URLs with branches and tags (#1431)
  * ``asv`` defaults to ``--force-reinstall`` now to facilitate ``compare`` and
    ``continuous`` for manually versioned projects (#1421)
- Drop removal of benchmark, docs and test directories from %%install section
- Update Requires from pyproject.toml
- Use Python 3.11 on SLE-15 by default
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * build is now the default backend for asv to install projects.
  * Partially skipped benchmarks will still have their results
    displayed.
  * asv will now correctly prepare all the build backend
    dependencies into base_requirements and the default
    build_command has been modified to allow fetching from PyPI.
  * The asv package no longer prepends the script execution
    directory unconditionally. Now we check for and remove the
    path only if it matches the directory that the runner script
    resides in.
  * The bdist wheels no longer include benchmarks and test.
  * The mamba plugin works correctly for newer versions (>=1.5)
    of libmambapy
  * The mamba plugin respects the MAMBARC environment if set,
    taking channels and channel priority from the file in the
    environment variable.
  * Fixed a bug where matrix requirements were dropped if an
    environment file was specified.
  * conda-forge is no longer a default channel for mamba.
  * asv now depends on virtualenv
* Tue Oct 24 2023 Dirk Müller <dmueller@suse.com>
- use setuptools_scm to get the right packaged version
* Mon Oct  9 2023 pgajdos@suse.com
- python-six is not required
* Mon Oct  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.1:
  * ``pip`` dependencies in ``environment.yml`` files for the
    ``mamba`` plugin are handled correctly (#1326)
  * ``asv.config.json`` matrix requirements no longer need
    ``pip+`` set explicitly for calling the ``pip`` solver for
    ``virtualenv``
  * ``asv`` will now use ``conda_environment_file`` if it exists
    (#1325)
  * ``asv`` timestamps via ``datetime`` are now Python 3.12
    compatible (#1331)
  * ``asv`` now provides ``asv[virtualenv]`` as an installable
    target
  * ``asv`` now uses Github Actions exclusively for Windows and
    Linux
* Mon Sep  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.0:
  * ``asv_runner`` is now used internally, making the addition of
    custom benchmark types viable (#1287)
  * Benchmarks can be skipped, both wholly and in part using new
    decorators ``skip_benchmark_if`` and ``skip_params_if``
  * Benchmarks can be skipped during their execution (after
    setup) by raising ``SkipNotImplemented`` (#1307)
  * Added ``default_benchmark_timeout`` to the configuration
    object, can also be
  * passed via ``-a timeout=NUMBER`` (#1308)
  * ``ASV_RUNNER_PATH`` can be set from the terminal to test
    newer versions of ``asv_runner`` (#1312)
  * Removed ``asv dev`` in favor of using ``asv run`` with the
    right arguments (#1200)
  * ``asv run`` and ``asv continuous`` don't implement the
    ``--strict`` option anymore, and they will always return
    a non-zero (i.e. ``2``) exit status if any benchmark fail.
  * Fixed ``install_timeout`` for ``conda`` (#1310)
* Thu Aug  4 2022 Otto Hollmann <otto.hollmann@suse.com>
-  Update to 0.5.1:
  * Bug Fixes
  * Packaging requirements-dev.txt file, used in setup.py. (#1013)
- Changes from 0.5:
  * New Features
  * Adding environment variables to build and benchmark commands. (#809, #833)
  * Added --strict option to asv run to set exit code on failure. (#865)
  * Added --no-stats option to asv compare and asv continuous. (#879)
  * Added --durations option to asv run and asv show for displaying benchmark
    run durations. (#838)
  * Added --date-period option to asv run for running benchmarks for commits
    separated by a constant time interval. (#835)
  * Web UI button to group regressions by benchmark. (#869)
  * Space-saving v2 file format for storing results. (#847)
  * timeraw_* benchmarks for measuring e.g. import times. (#832)
  * Support for using conda environment files for env setup. (#793)
  * API Changes
  * Results file format change requires asv update to update old data to v2
    format.
  * The configuration syntax for "matrix", "exclude", and "include" in
    asv.conf.json has changed. The old syntax is still supported, unless you
    are installing packages named req, env, env_nobuild.
  * Bug Fixes
  * When an asv find step fails due to timeout, assume runtime equal to
    timeout to allow bisection to proceed (#768)
  * Minor fixes and improvements (#897, #896, #888, #881, #877, #876, #875,
    [#861], #870, #868, #867, #866, #864, #863, #857, #786, #854, #855, #852,
    [#850], #844, #843, #842, #839, #841, #840, #837, #836, #834, #831, #830,
    [#829], #828, #826, #825, #824)
  * Other Changes and Additions
  * Uniqueness of repr() for param objects is now guaranteed by suffixing
    unique identifier corresponding to order of appearance. (#771)
  * Memory addresses are now stripped from the repr() of param elements,
    allowing comparison across multiple runs. (#771)
  * asv dev is now equivalent to asv run with --python=same default. (#874)
  * asv continuous by default now records measurement samples, for better
    comparison statistics. (#878)
  * ASV now uses PEP 518 pyproject.toml in packaging. (#853)
* Tue May 18 2021 pgajdos@suse.com
- version update to 0.4.2
  * Do not supply ``--no-site-packages`` to virtualenv, as it is on by
    default and no longer supported. (#917)
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Use more detailed description.
* Mon Jul 22 2019 Michal Vyskocil <mvyskocil@opensuse.org>
- Initial release of python-asv 0.4.1
